# -*- coding: cp1252 -*-
#------------------------------------------------------------------------------
# Name:        01_GIS_Analyse.py
# Version:     1.1
#
# Purpose:     Strategische Revitalisierungsplanung Seeufer (IGKB): GIS-Analyse
#
# Author:      Sigmaplan AG, Bern
#
# Last Edited: 06.01.2020
#
# Copyright:   (c) BAFU
#
# Python:      2.7.5
# ArcGIS:      10.4.1 (ArcView License)
#------------------------------------------------------------------------------

import os
import arcpy
import datetime

starttime = datetime.datetime.now()

## *********************************************************************************************************
# Benutzereingaben und Umgebung
in_oekmo = arcpy.GetParameterAsText(0) + "\\"
in_ID_Uferlinie = arcpy.GetParameterAsText(1)
in_oekmo_AbschID = arcpy.GetParameterAsText(2)
in_Refugium = arcpy.GetParameterAsText(3)
in_Ufergehoelz = arcpy.GetParameterAsText(4)
in_Hindernis = arcpy.GetParameterAsText(5)
in_Uferverbauung = arcpy.GetParameterAsText(6)
in_Durchgaengigkeit = arcpy.GetParameterAsText(7)
in_Hinterland = arcpy.GetParameterAsText(8)
in_Ufertyp = arcpy.GetParameterAsText(9)
in_BreiteFWZ = arcpy.GetParameterAsText(10)
in_Uferlinie = arcpy.GetParameterAsText(11)
in_Deltabildung = arcpy.GetParameterAsText(12)
in_Ufersubstrat = arcpy.GetParameterAsText(13)
in_Litoralsubstrat = arcpy.GetParameterAsText(14)
in_Totholz = arcpy.GetParameterAsText(15)
in_Roehricht = arcpy.GetParameterAsText(16)
in_Makrophyten = arcpy.GetParameterAsText(17)
in_Algen = arcpy.GetParameterAsText(18)
in_Kinderstube = arcpy.GetParameterAsText(19)
in_oekmowert = arcpy.GetParameterAsText(20)
in_BAUS = arcpy.GetParameterAsText(21) + "\\"
in_BAUS_AbschID = arcpy.GetParameterAsText(22)
in_BAUS_Attr = arcpy.GetParameterAsText(23)
in_OEB = arcpy.GetParameterAsText(24) + "\\"
in_OEB_AbschID = arcpy.GetParameterAsText(25)
in_OEB_Attr = arcpy.GetParameterAsText(26)
out_gdb = arcpy.GetParameterAsText(27) + "\\"
arcpy.env.workspace = out_gdb
arcpy.env.overwriteOutput = True


## *********************************************************************************************************
# Weitere Variablen und Listen

# Listen Attribute
allg_Attribute = ['OBJECTID', 'Shape', 'Shape_Length']
Attribute = ['ID_Uferlinie', 'ABSCH_ID', 'REFUGIUM', 'UFERGEH', 'HINDERNIS', 'UFERVERBAU', 'BIODURCH', # IGKB-Attribute
             'HINTERLAND', 'UFERTYP', 'BREITEFWZ', 'UFERLINIE', 'DELTA', 'UFERSUB', # IGKB-Attribute
             'LITSUB', 'TOTHOLZ', 'ROEHRICHT', 'MAKROPHYT', 'ALGEN', 'KINDERST', 'INDEX', # IGKB-Attribute
             'RBUS', 'RBFWZ', 'RBUL', 'RBHL', 'RB',
             'BAUS', 'BAFWZ', 'UTUS', 'UTFWZ',
             'ULWUS', 'ULWFWZ', 'HLW','APUS', 'APFWZ',
             'APP', 'AP', 'OEB', 'GISNP', 'GISN']
# unterteilt wegen Reihenfolge in Tabelle REVIT
Attribute_short1 = ['RBUS', 'RBFWZ', 'RBUL', 'RBHL', 'RB']
Attribute_float1 = ['BAUS', 'BAFWZ', 'UTUS', 'UTFWZ']
Attribute_short2 = ['ULWUS', 'ULWFWZ', 'HLW','APUS', 'APFWZ',
                    'APP', 'AP']
Attribute_float2 = ['OEB']
Attribute_short3 = ['GISNP', 'GISN']
Attribute_float_temp = ['W_RBUS', 'W_RBFWZ', 'W_RBUL', 'W_RBHL', 'W_RB', 'W_BAFWZ', 'W_UTUS', 'W_UTFWZ']

# Domains
values_JaNein = {(0,"Nein"), (1,"Ja")}
values_RB = {(0,"naturnah, natrlich"), (2,"wenig beeintrchtigt"), (4,"beeintrchtigt"), (6,"naturfremd"), (8,"knstlich"), (99,"nicht bestimmt")} # Revitalisierungsbedarf
values_BA = {("0.5","gross"), ("1","mittel"), ("2","gering"), ("0","kein")} # baulicher Aufwand
values_AP = {(1,"gering"),(2,"mittel"), (3,"hoch")} # Aufwertungspotenzial
values_Nutzen = {(1,"kein/gering"), (2,"mittel"), (3,"hoch")}
values_Frist= {(1,"bis 2024"), (2,"2025-28"), (3,"2029-32"), (4,"2033-36"), (5,"2037-40"), (6,"2041 oder spter"), (0,"nicht bestimmt")}

list_domain = [
    ("domJaNein", "ja / nein", "SHORT", "CODED", values_JaNein),
    ("domRB", "Revitalisierungsbedarf", "SHORT", "CODED", values_RB),
    ("domBA", "Baulicher Aufwand", "FLOAT", "CODED", values_BA),
    ("domAP", "Aufwertungspotenzial", "SHORT", "CODED", values_AP),
    ("domNutzen", "Nutzen", "SHORT", "CODED",  values_Nutzen),
    ("domFrist", "Fristen", "SHORT", "CODED", values_Frist)
    ]

attribute_domain = [
    ("REVIT", "RBUS", "domRB"),
    ("REVIT", "RBFWZ", "domRB"),
    ("REVIT", "RBUL", "domRB"),
    ("REVIT", "RBHL", "domRB"),
    ("REVIT", "RB", "domRB"),
    ("REVIT", "BAUS", "domBA"),
    ("REVIT", "BAFWZ", "domBA"),
    ("REVIT", "AP", "domAP"),
    ("REVIT", "GISN", "domNutzen")
    ]


## *********************************************************************************************************
# Funktionen

def msgOut(msg):
    print msg
    arcpy.AddMessage(msg)

def errOut(err):
    print err
    print arcpy.GetMessages()
    print datetime.datetime.now()-starttime
    arcpy.AddError(err)
    arcpy.AddError(arcpy.GetMessages())
    arcpy.AddError(datetime.datetime.now()-starttime)

def oekmo(nn_oekmo):
    """ Wandelt die stetigen IGKB-Oekomorphologiewerte in 0, 2, 4, 6, oder 8 um.
    """ 
    try:
        if nn_oekmo <= 1.8:
            nn_oekmo = 0
        elif nn_oekmo <= 2.6:
            nn_oekmo = 2
        elif nn_oekmo <= 3.4:
            nn_oekmo = 4
        elif nn_oekmo <= 4.2:
            nn_oekmo = 6
        elif nn_oekmo <= 5:
            nn_oekmo = 8
        else:
            nn_oekmo = 0
        return nn_oekmo
    except:
        print "\nERROR: Fehler in Berechnung Revitalisierungsbedarf"
        print "Dauer: ", datetime.datetime.now()-starttime

## *********************************************************************************************************
#  Schritt 1a: Oekomorphologie
try:
    msgOut(u"\nkomorphologie kopieren...")
    arcpy.FeatureClassToFeatureClass_conversion(in_oekmo, out_gdb, "REVIT")

    arcpy.AlterField_management(out_gdb + "REVIT", str(in_ID_Uferlinie), "temp_ID_Uferlinie")   # Umweg wegen Case Sensitivity
    arcpy.AlterField_management(out_gdb + "REVIT", "temp_ID_Uferlinie", "ID_Uferlinie")
    arcpy.AlterField_management(out_gdb + "REVIT", str(in_oekmo_AbschID), "temp_ABSCH_ID")
    arcpy.AlterField_management(out_gdb + "REVIT", "temp_ABSCH_ID", "ABSCH_ID")
    arcpy.AlterField_management(out_gdb + "REVIT", str(in_Refugium), "temp_REFUGIUM")
    arcpy.AlterField_management(out_gdb + "REVIT", "temp_REFUGIUM", "REFUGIUM")
    arcpy.AlterField_management(out_gdb + "REVIT", str(in_Ufergehoelz), "temp_UFERGEH")
    arcpy.AlterField_management(out_gdb + "REVIT", "temp_UFERGEH", "UFERGEH")
    arcpy.AlterField_management(out_gdb + "REVIT", str(in_Hindernis), "temp_HINDERNIS")
    arcpy.AlterField_management(out_gdb + "REVIT", "temp_HINDERNIS", "HINDERNIS")
    arcpy.AlterField_management(out_gdb + "REVIT", str(in_Uferverbauung), "temp_UFERVERBAU")
    arcpy.AlterField_management(out_gdb + "REVIT", "temp_UFERVERBAU", "UFERVERBAU")
    arcpy.AlterField_management(out_gdb + "REVIT", str(in_Durchgaengigkeit), "temp_BIODURCH")
    arcpy.AlterField_management(out_gdb + "REVIT", "temp_BIODURCH", "BIODURCH")
    arcpy.AlterField_management(out_gdb + "REVIT", str(in_Hinterland), "temp_HINTERLAND")
    arcpy.AlterField_management(out_gdb + "REVIT", "temp_HINTERLAND", "HINTERLAND")
    arcpy.AlterField_management(out_gdb + "REVIT", str(in_Ufertyp), "temp_UFERTYP")
    arcpy.AlterField_management(out_gdb + "REVIT", "temp_UFERTYP", "UFERTYP")
    arcpy.AlterField_management(out_gdb + "REVIT", str(in_BreiteFWZ), "temp_BREITEFWZ")
    arcpy.AlterField_management(out_gdb + "REVIT", "temp_BREITEFWZ", "BREITEFWZ")
    arcpy.AlterField_management(out_gdb + "REVIT", str(in_Uferlinie), "temp_UFERLINIE")
    arcpy.AlterField_management(out_gdb + "REVIT", "temp_UFERLINIE", "UFERLINIE")
    arcpy.AlterField_management(out_gdb + "REVIT", str(in_Deltabildung), "temp_DELTA")
    arcpy.AlterField_management(out_gdb + "REVIT", "temp_DELTA", "DELTA")
    arcpy.AlterField_management(out_gdb + "REVIT", str(in_Ufersubstrat), "temp_UFERSUB")
    arcpy.AlterField_management(out_gdb + "REVIT", "temp_UFERSUB", "UFERSUB")
    arcpy.AlterField_management(out_gdb + "REVIT", str(in_Litoralsubstrat), "temp_LITSUB")
    arcpy.AlterField_management(out_gdb + "REVIT", "temp_LITSUB", "LITSUB")
    arcpy.AlterField_management(out_gdb + "REVIT", str(in_Totholz), "temp_TOTHOLZ")
    arcpy.AlterField_management(out_gdb + "REVIT", "temp_TOTHOLZ", "TOTHOLZ")
    arcpy.AlterField_management(out_gdb + "REVIT", str(in_Roehricht), "temp_ROEHRICHT")
    arcpy.AlterField_management(out_gdb + "REVIT", "temp_ROEHRICHT", "ROEHRICHT")
    arcpy.AlterField_management(out_gdb + "REVIT", str(in_Makrophyten), "temp_MAKROPHYT")
    arcpy.AlterField_management(out_gdb + "REVIT", "temp_MAKROPHYT", "MAKROPHYT")
    arcpy.AlterField_management(out_gdb + "REVIT", str(in_Algen), "temp_ALGEN")
    arcpy.AlterField_management(out_gdb + "REVIT", "temp_ALGEN", "ALGEN")
    arcpy.AlterField_management(out_gdb + "REVIT", str(in_Kinderstube), "temp_KINDERST")
    arcpy.AlterField_management(out_gdb + "REVIT", "temp_KINDERST", "KINDERST")
    arcpy.AlterField_management(out_gdb + "REVIT", str(in_oekmowert), "temp_INDEX")
    arcpy.AlterField_management(out_gdb + "REVIT", "temp_INDEX", "INDEX")

    msgOut(u"\nAttribute ergnzen...")
    for Attribut in Attribute_short1:
        arcpy.AddField_management(out_gdb + "REVIT", Attribut, "SHORT")
    for Attribut in Attribute_float1:
        arcpy.AddField_management(out_gdb + "REVIT", Attribut, "FLOAT")
    for Attribut in Attribute_short2:
        arcpy.AddField_management(out_gdb + "REVIT", Attribut, "SHORT")
    for Attribut in Attribute_float2:
        arcpy.AddField_management(out_gdb + "REVIT", Attribut, "FLOAT")
    for Attribut in Attribute_short3:
        arcpy.AddField_management(out_gdb + "REVIT", Attribut, "SHORT")
    for Attribut in Attribute_float_temp:
        arcpy.AddField_management(out_gdb + "REVIT", Attribut, "FLOAT")

    msgOut(u"\nRevitalisierungsbedarf berechnen...")
    with arcpy.da.UpdateCursor(out_gdb + "REVIT", ["W_RBUS", "REFUGIUM", "UFERGEH",
                                                   "W_RBFWZ", "HINDERNIS",
                                                   "W_RBUL", "UFERVERBAU", "BIODURCH",
                                                   "W_RBHL", "HINTERLAND",
                                                   "W_RB", "INDEX",
                                                   "W_UTUS", "UFERTYP",
                                                   "W_UTFWZ", "BREITEFWZ",
                                                   "W_BAFWZ",
                                                   "INDEX"
                                                   ]) as rows:
        for row in rows:   
            # RBUS
            if row[1] < 1 or row[1] > 5:
                if row[2] < 1 or row[2] > 5:
                    row[0] = 0
                else:
                    row[0] = round(row[2], 2)
            elif row[2] < 1 or row[2] > 5:
                row[0] = round(row[1], 2)
            else:
                row[0] = round((row[1]+row[2]) / 2, 2)
            # RBFWZ
            if row[4] < 1 or row[4] > 6:
                row[3] = 0
            else:
                row[3] = round(row[4], 2)
            # RBUL
            if row[6] < 1 or row[6] > 5:
                if row[7] < 1 or row[7] > 5:
                    row[5] = 0
                else:
                    row[5] = round(row[7], 2)
            elif row[7] < 1 or row[7] > 5:
                row[5] = round(row[6], 2)
            else:
                row[5] = round((row[6]+row[7]) / 2, 2)
            # RBHL
            if row[9] < 1 or row[9] > 5:
                row[8] = 0
            else:
                row[8] = round(row[9], 2)
            # RB
            if row[11] < 1 or row[11] > 5:
                row[10] = 0
            else:
                row[10] = round(row[11], 2)            
            # UTUS
            if row[13] < 1 or row[13] > 5:
                row[12] = 0
            else:
                row[12] = round(row[13], 2)   
            # UTFWZ
            if row[15] < 1 or row[15] > 5:
                row[14] = 0
            else:
                row[14] = round(row[15], 2)   
            # BAFWZ
            if row[4] < 1 or row[4] > 6:
                row[16] = 0
            else:
                row[16] = round(row[4], 2)
            # INDEX bzw. Oekmowert
            if row[11] < 1 or row[11] > 5:
                row[17] = 0
            else:
                row[17] = round(row[11], 2)  
            rows.updateRow(row)
        del row
        del rows

    with arcpy.da.UpdateCursor(out_gdb + "REVIT", ["RBUS", "W_RBUS", "RBFWZ", "W_RBFWZ",
                                                   "RBUL", "W_RBUL", "RBHL", "W_RBHL", "RB", "W_RB"
                                                   ]) as rows:
        for row in rows:
            row[0] = oekmo(row[1])
            row[2] = oekmo(row[3])
            row[4] = oekmo(row[5])
            row[6] = oekmo(row[7])
            row[8] = oekmo(row[9])
            rows.updateRow(row)
        del row
        del rows

    with arcpy.da.UpdateCursor(out_gdb + "REVIT", ["UTUS", "W_UTUS", 
                                                   "UTFWZ", "W_UTFWZ", 
                                                   "BAFWZ", "W_BAFWZ", 
                                                   ]) as rows:
        for row in rows:
            # UTUS
            if row[1] == 1:
                row[0] = 0.5
            elif row[1] == 2:
                row[0] = 1
            elif row[1] == 3:
                row[0] = 1.5
            else:
                row[0] = 1
            # UTFWZ
            if row[3] == 1:
                row[2] = 0.5
            elif row[3] == 2:
                row[2] = 0.5
            elif row[3] == 3:
                row[2] = 1
            elif row[3] == 4:
                row[2] = 1.5
            elif row[3] == 5:
                row[2] = 1.5
            elif row[3] == 6:
                row[2] = 1.5
            else:
                row[2] = 1
            # BAFWZ
            if row[5] == 1:
                row[4] = 0
            elif row[5] == 2:
                row[4] = 2
            elif row[5] == 3:
                row[4] = 2
            elif row[5] == 4:
                row[4] = 1
            elif row[5] == 5:
                row[4] = 0.5
            else:
                row[4] = 0
            rows.updateRow(row)
        del row
        del rows

    for attr in Attribute_float_temp:
        arcpy.DeleteField_management(out_gdb + "REVIT", str(attr))

except:
    errOut(u"\nERROR: Fehler beim Berechnen der Zwischenresultate komorphologie.")
    sys.exit(1)


## *********************************************************************************************************
#  Schritt 1b: Baulicher Aufwand Uferstreifen, oekologische und landschaftliche Bedeutung
try:
    msgOut(u"\nBaulicher Aufwand Uferstreifen und kologische und landschaftliche Bedeutung zuweisen...")
    # Join mit baulichem Aufwand (0=kein Aufwand; 2=geringer Aufwand; 1=mittlerer Aufwand; 0.5=grosser Aufwand)
    arcpy.JoinField_management(out_gdb + "REVIT", "ABSCH_ID", in_BAUS, in_BAUS_AbschID, in_BAUS_Attr)   
    if str(in_BAUS_Attr) == "BAUS":
        with arcpy.da.UpdateCursor(out_gdb + "REVIT", ["BAUS", "BAUS_1"]) as rows:
            for row in rows:
                if round(row[1], 1) == 0.5:
                    row[0] = 0.5
                elif round(row[1], 0) == 1:
                    row[0] = 1
                elif round(row[1], 0) == 2:
                    row[0] = 2
                else:
                    row[0] = 0
                rows.updateRow(row)
        arcpy.DeleteField_management(out_gdb + "REVIT", ["BAUS_1"])
    else:
        with arcpy.da.UpdateCursor(out_gdb + "REVIT", ["BAUS", in_BAUS_Attr]) as rows:
            for row in rows:
                if round(row[1], 1) == 0.5:
                    row[0] = 0.5
                elif round(row[1], 0) == 1:
                    row[0] = 1
                elif round(row[1], 0) == 2:
                    row[0] = 2
                else:
                    row[0] = 0
                rows.updateRow(row)                
        arcpy.DeleteField_management(out_gdb + "REVIT", [in_BAUS_Attr])

    # Join mit oekologischer und landschaftlicher Bedeutung (Faktoren zwischen 0.7 und 1.3)
    arcpy.JoinField_management(out_gdb + "REVIT", "ABSCH_ID", in_OEB, in_OEB_AbschID, in_OEB_Attr)   
    if str(in_OEB_Attr) == "OEB":
        with arcpy.da.UpdateCursor(out_gdb + "REVIT", ["OEB", "OEB_1"]) as rows:
            for row in rows:
                if float(row[1]) >= float(0.7) and float(row[1]) <= float(1.3):
                    row[0] = round(row[1], 1)
                else:
                    row[0] = 1
                rows.updateRow(row)
                rows.updateRow(row)
        arcpy.DeleteField_management(out_gdb + "REVIT", ["OEB_1"])
    else:
        with arcpy.da.UpdateCursor(out_gdb + "REVIT", ["OEB", in_OEB_Attr]) as rows:
            for row in rows:
                if float(row[1]) >= float(0.7) and float(row[1]) <= float(1.3):
                    row[0] = round(row[1], 1)
                else:
                    row[0] = 1
                rows.updateRow(row)                
        arcpy.DeleteField_management(out_gdb + "REVIT", [in_OEB_Attr])

except:
    errOut(u"\nERROR: Fehler beim Zuweisen des baulichen Aufwands und der kologischen und landschaftlichen Bedeutung.")
    sys.exit(1)

## *********************************************************************************************************
#  Schritt 1c: Berechnung Aufwertungspotenzial, theoretischer Nutzen fuer Natur und Landschaft (vor Expertenbereinigung)
try:
    msgOut(u"\nAttribute berechnen...")

    # leere Felder bereinigen
    with arcpy.da.UpdateCursor(out_gdb + "REVIT", ["OEB", "UTFWZ", "UTUS", "APFWZ", "RBFWZ", "BAFWZ", "APUS", "RBUS", "BAUS"]) as rows:
        for row in rows:
            if float(row[0]) == 0:
                row[0] = 1
            elif float(row[0]) == '':
                row[0] = 1
            if float(row[1]) == 0:
                row[1] = 1
            elif row[1] == '':
                row[1] = 1
            if float(row[2]) == 0:
                row[2] = 1
            elif row[2] == '':
                row[2] = 1
            row[3] = float(row[4]) * float(row[5])
            row[6] = float(row[7]) * float(row[8])
            rows.updateRow(row)

    with arcpy.da.UpdateCursor(out_gdb + "REVIT", ["RBUL", "RBUS", "UTUS", "ULWUS", "RBFWZ", "UTFWZ", "ULWFWZ", "RBHL", "HLW"]) as rows:
        for row in rows:
            if float(row[0]) > float(row[1]):
                if float(row[2]) >= 1:
                    row[3] = 2 * ((float(row[0]) - float(row[1]))/2)
                else:
                    row[3] = 0
            else:
                row[3] = 0
            if float(row[0]) > float(row[4]):
                if float(row[5]) >= 1:
                    row[6] = 4 * ((float(row[0]) - float(row[4]))/2)
                else:
                    row[6] = 0
            else:
                row[6] = 0
            if row[7] in (0, 2):
                row[8] = 3
            else:
                row[8] = 0                         
            rows.updateRow(row)

    with arcpy.da.UpdateCursor(out_gdb + "REVIT", ["APP", "GISNP", "APFWZ", "UTFWZ", "APUS", "UTUS", "ULWUS", "ULWFWZ", "HLW", "OEB"]) as rows:
        for row in rows:
            row[0] = float(row[2]) * float(row[3]) + float(row[4]) * float(row[5]) + float(row[6]) + float(row[7]) + float(row[8])
            row[1] = round((float(row[2]) * float(row[3]) + float(row[4]) * float(row[5]) + float(row[6]) + float(row[7]) + float(row[8])) * float(row[9]), 0)                       
            rows.updateRow(row)

    with arcpy.da.UpdateCursor(out_gdb + "REVIT", ["AP", "APP"]) as rows:
        for row in rows:
            if row[1] <= 7:
                row[0] = 1
            elif row[1] <= 14:
                row[0] = 2
            else:
                row[0] = 3
            rows.updateRow(row)
        del row
        del rows     

    list_attr = [a.name for a in arcpy.ListFields(out_gdb + "REVIT")]
    for attr in list_attr:
        if attr not in allg_Attribute + Attribute:
            arcpy.DeleteField_management(out_gdb + "REVIT", str(attr))

except:
    errOut(u"\nERROR: Fehler bei der Berechnung des GIS-Nutzens.")
    sys.exit(1)

## *********************************************************************************************************
#  Schritt 1d: Domains und Darstellung
try:
    msgOut(u"\nDomains erstellen...")
    desc = arcpy.Describe(out_gdb)
    domains = desc.domains
    for domain in domains:
        arcpy.DeleteDomain_management(out_gdb, domain)
    for domain in list_domain:
        arcpy.CreateDomain_management(out_gdb, domain[0], domain[1], domain[2], domain[3])
        for value in domain[4]:
            arcpy.AddCodedValueToDomain_management(out_gdb, domain[0], value[0], value[1])
        arcpy.SortCodedValueDomain_management(out_gdb, domain[0], "CODE", "ASCENDING")
    msgOut(u"\nDomains zuweisen...")
    for attribute in attribute_domain:
        arcpy.AssignDomainToField_management(out_gdb + str(attribute[0]), attribute[1], attribute[2])
    
except:
    errOut(u"\nERROR: Fehler beim Erstellen der Domains.")
    sys.exit(1)

## *********************************************************************************************************
#  Benutzeranweisung
msgOut("\n" + u"Tabelle REVIT wurde generiert. Bevor mit Schritt 2 fortgefahren werden kann, mssen Klassengrenzen fr den GIS-Nutzen bestimmt werden." + "\n")
