# -*- coding: cp1252 -*-
#------------------------------------------------------------------------------
# Name:        02_GIS_Nutzen.py
# Version:     1.0
#
# Purpose:     Strategische Revitalisierungsplanung Seeufer (IGKB): GIS-Analyse
#
# Author:      Sigmaplan AG, Bern
#
# Last Edited: 23.04.2019
#
# Copyright:   (c) BAFU
#
# Python:      2.7.5
# ArcGIS:      10.4.1 (ArcView License)
#------------------------------------------------------------------------------

import os
import arcpy
import datetime

starttime = datetime.datetime.now()

## *********************************************************************************************************
# Benutzereingaben und Umgebung
in_gdb = arcpy.GetParameterAsText(0) + "\\"
untere_Grenze = arcpy.GetParameterAsText(1)
obere_Grenze = arcpy.GetParameterAsText(2)
arcpy.env.workspace = in_gdb
arcpy.env.overwriteOutput = True

## *********************************************************************************************************
# Weitere Variablen und Listen
# Listen Attribute
allg_Attribute = ['OBJECTID', 'Shape', 'Shape_Length']
Attribute_PLAUS = ['ID_Uferlinie', 'ABSCH_ID', 'GISN', 'NUTZEN', 'BEGRUEND']
Attribute_PRIO = ['ID_Uferlinie', 'ABSCH_ID', 'FRIST', 'MASSN1', 'MASSN2', 'MASSN3', 'MASSN4', 'MASSN5', 'MASSN6', 'MASSN7', 'MASSN8', 'MASSN9', 'MASSN0', 'BEM_MASSN']
list_Massnahmen = ['MASSN1', 'MASSN2', 'MASSN3', 'MASSN4', 'MASSN5', 'MASSN6', 'MASSN7', 'MASSN8', 'MASSN9', 'MASSN0']

list_lyr = ["fc_REVIT_GISN.lyr", "fc_REVIT_RB.lyr", "fc_REVIT_AP.lyr", "fc_REVIT_OEB.lyr", "fc_PLAUS.lyr"]

# Pfade
path_script = os.path.dirname(sys.argv[0])
path_in = path_script.replace("\\", r"\\")
path_db = in_gdb
path_out = os.path.dirname(os.path.dirname(path_db))
path_out = path_out.replace("\\", r"\\")

# Domains
attribute_domain = [
    ("PLAUS", "NUTZEN", "domNutzen"),
    ("PRIO", "FRIST", "domFrist"),
    ("PRIO", "MASSN1", "domJaNein"),
    ("PRIO", "MASSN2", "domJaNein"),
    ("PRIO", "MASSN3", "domJaNein"),
    ("PRIO", "MASSN4", "domJaNein"),
    ("PRIO", "MASSN5", "domJaNein"),
    ("PRIO", "MASSN6", "domJaNein"),
    ("PRIO", "MASSN7", "domJaNein"),
    ("PRIO", "MASSN8", "domJaNein"),
    ("PRIO", "MASSN9", "domJaNein"),
    ("PRIO", "MASSN0", "domJaNein")
    ]

## *********************************************************************************************************
# Funktionen

def msgOut(msg):
    print msg
    arcpy.AddMessage(msg)

def errOut(err):
    print err
    print arcpy.GetMessages()
    print datetime.datetime.now()-starttime
    arcpy.AddError(err)
    arcpy.AddError(arcpy.GetMessages())
    arcpy.AddError(datetime.datetime.now()-starttime)

## *********************************************************************************************************
#  Schritt 2a: GIS-Nutzen klassieren
try:
    msgOut(u"\nGIS-Nutzen klassieren...")
    with arcpy.da.UpdateCursor(in_gdb + "REVIT", ["GISN", "GISNP"]) as rows:
        for row in rows:
            if row[1] <= int(untere_Grenze):
                row[0] = 1
                rows.updateRow(row)
            elif row[1] >= int(obere_Grenze):
                row[0] = 3
                rows.updateRow(row)
            else:
                row[0] = 2
                rows.updateRow(row)    

except:
    errOut(u"\nERROR: Fehler bei der Klassierung des GIS-Nutzens.")
    sys.exit(1)   

## *********************************************************************************************************
#  Schritt 2b: lyr-Files kopieren
try:
    msgOut(u"\nlyr-Files kopieren...")
    for lyr in list_lyr:
        arcpy.Copy_management(path_in + "\\lyr_fc\\" + str(lyr), path_out + "\\"  + str(lyr))

except:
    errOut(u"\nERROR: Fehler beim Kopieren der lyr-Files.")
    sys.exit(1)

## *********************************************************************************************************
# Schritt 2c: Domains, Hilfstabellen fuer naechste Schritte
try:
    msgOut(u"\nHilfstabellen erstellen...")
    arcpy.FeatureClassToFeatureClass_conversion(in_gdb + "REVIT", in_gdb, "PLAUS") # Kopie, damit AbschnittsIDs gleich

    list_attr = [a.name for a in arcpy.ListFields(in_gdb + "PLAUS")] # alle unnoetigen Felder loeschen
    for attr in list_attr:
        if attr not in allg_Attribute + Attribute_PLAUS:
            arcpy.DeleteField_management(in_gdb + "PLAUS", str(attr))

    arcpy.AddField_management(in_gdb + "PLAUS", "NUTZEN", "SHORT")
    arcpy.AddField_management(in_gdb + "PLAUS", "BEGRUEND", "TEXT", "", "", 255)
    
    with arcpy.da.UpdateCursor(in_gdb + "PLAUS", ["GISN", "NUTZEN"]) as rows:
        for row in rows:
            row[1] = row[0]
            rows.updateRow(row)

    arcpy.FeatureClassToFeatureClass_conversion(in_gdb + "REVIT", in_gdb, "PRIO") # Kopie, damit AbschnittsIDs gleich
    
    list_attr = [a.name for a in arcpy.ListFields(in_gdb + "PRIO")] # alle unnoetigen Felder loeschen
    for attr in list_attr:
        if attr not in allg_Attribute + Attribute_PRIO:
            arcpy.DeleteField_management(in_gdb + "PRIO", str(attr))
            
    arcpy.AddField_management(in_gdb + "PRIO", "FRIST", "SHORT")
    for Massnahme in list_Massnahmen:
        arcpy.AddField_management(in_gdb + "PRIO", Massnahme, "SHORT")
        arcpy.AssignDefaultToField_management(in_gdb + "PRIO", Massnahme, "0")
    arcpy.AlterField_management(in_gdb + "PRIO", "MASSN1", new_field_alias = "Rckverlegung / Beseitigung Uferverbau")
    arcpy.AlterField_management(in_gdb + "PRIO", "MASSN2", new_field_alias = "Flachuferschttung")
    arcpy.AlterField_management(in_gdb + "PRIO", "MASSN3", new_field_alias = "Landseitige Terrainanpassung")
    arcpy.AlterField_management(in_gdb + "PRIO", "MASSN4", new_field_alias = "Wiederherstellung Flachwasserzone")
    arcpy.AlterField_management(in_gdb + "PRIO", "MASSN5", new_field_alias = "Schttung Inseln")
    arcpy.AlterField_management(in_gdb + "PRIO", "MASSN6", new_field_alias = "Strukturierung Ufer")
    arcpy.AlterField_management(in_gdb + "PRIO", "MASSN7", new_field_alias = "Schaffung Feuchtgebiete / Tmpel in Uferzone")
    arcpy.AlterField_management(in_gdb + "PRIO", "MASSN8", new_field_alias = "Schilfpflanzungen / -schutzmassnahmen")
    arcpy.AlterField_management(in_gdb + "PRIO", "MASSN9", new_field_alias = "Entfernung Anlagen aus Flachwasserzone")
    arcpy.AlterField_management(in_gdb + "PRIO", "MASSN0", new_field_alias = "Sonstige")
    arcpy.AddField_management(in_gdb + "PRIO", "BEM_MASSN", "TEXT", "", "", 255)

    with arcpy.da.UpdateCursor(in_gdb + "PRIO", ["MASSN1", "MASSN2", "MASSN3", "MASSN4", "MASSN5", "MASSN6", "MASSN7", "MASSN8", "MASSN9", "MASSN0"]) as rows:
        for row in rows:
            row[0] = 0
            row[1] = 0
            row[2] = 0
            row[3] = 0
            row[4] = 0
            row[5] = 0
            row[6] = 0
            row[7] = 0
            row[8] = 0
            row[9] = 0
            rows.updateRow(row)
    
    msgOut(u"\nDomains zuweisen...")
    for attribute in attribute_domain:
        arcpy.AssignDomainToField_management(in_gdb + str(attribute[0]), attribute[1], attribute[2])

except:
    errOut(u"\nERROR: Fehler beim Zuweisen der Domains.")
    sys.exit(1)

## *********************************************************************************************************
#  Benutzeranweisung
msgOut("\n" + u"Der GIS-Nutzen wurde berechnet und in der Featureclass REVIT erfasst." + "\n" +
       u"Sie ist die Basis fr die Expertenplausibilisierung. Bereinigungen der Experten werden in der Featureclass PLAUS erfasst. Anschliessend kann Schritt 3 Plausibilisierung durchgefhrt werden." + "\n")


