# -*- coding: cp1252 -*-
#------------------------------------------------------------------------------
# Name:        03_Plausibilisierung.py
# Version:     1.0
#
# Purpose:     Strategische Revitalisierungsplanung Seeufer (IGKB): GIS-Analyse
#
# Author:      Sigmaplan AG, Bern
#
# Last Edited: 23.04.2019
#
# Copyright:   (c) BAFU
#
# Python:      2.7.5
# ArcGIS:      10.4.1 (ArcView License)
#------------------------------------------------------------------------------

import os
import arcpy
import datetime

starttime = datetime.datetime.now()

## *********************************************************************************************************
# Benutzereingaben und Umgebung
in_gdb = arcpy.GetParameterAsText(0) + "\\"
arcpy.env.workspace = in_gdb
arcpy.env.overwriteOutput = True

## *********************************************************************************************************
# Weitere Variablen und Listen

list_lyr = ["fc_REVIT_PLAUS.lyr", "fc_PRIO.lyr"]

# Pfade
path_script = os.path.dirname(sys.argv[0])
path_in = path_script.replace("\\", r"\\")
path_db = in_gdb
path_out = os.path.dirname(os.path.dirname(path_db))
path_out = path_out.replace("\\", r"\\")

## *********************************************************************************************************
# Funktionen

def msgOut(msg):
    print msg
    arcpy.AddMessage(msg)

def errOut(err):
    print err
    print arcpy.GetMessages()
    print datetime.datetime.now()-starttime
    arcpy.AddError(err)
    arcpy.AddError(arcpy.GetMessages())
    arcpy.AddError(datetime.datetime.now()-starttime)
    
## *********************************************************************************************************
#  Schritt 3a: GIS-Nutzen plausibilisieren
try:
    msgOut(u"\nFeatureclass Plausibilisierung erstellen...")
    arcpy.FeatureClassToFeatureClass_conversion(in_gdb + "PLAUS", in_gdb, "REVIT_PLAUS")
    
    with arcpy.da.UpdateCursor(in_gdb + "REVIT_PLAUS", ["GISN", "NUTZEN", "BEGRUEND"]) as rows:
        for row in rows:
            if row[1] < 1:
                row[1] = row[0]
            elif row[1] == row[0]:
                row[2] = ''
            rows.updateRow(row)
        del row
        del rows

except:
    errOut(u"ERROR: Fehler bei der Plausibilisierungs-Featureclass.")
    sys.exit(1)

## *********************************************************************************************************
#  Schritt 3b: lyr-Files kopieren
try:
    msgOut(u"\nlyr-Files kopieren...")
    for lyr in list_lyr:
        arcpy.Copy_management(path_in + "\\lyr_fc\\" + str(lyr), path_out + "\\"  + str(lyr))

except:
    errOut(u"\nERROR: Fehler beim Kopieren der lyr-Files.")
    sys.exit(1)

## *********************************************************************************************************
#  Benutzeranweisung
msgOut("\n" + u"Featureclass REVIT_PLAUS wurde generiert. Priorisierungen werden in der Featureclass PRIO erfasst. Anschliessend kann Schritt 4 Priorisierung durchgefhrt werden." + "\n")
