# -*- coding: cp1252 -*-
#------------------------------------------------------------------------------
# Name:        05_Export.py
# Version:     1.1
#
# Purpose:     Strategische Revitalisierungsplanung Seeufer (IGKB): GIS-Analyse
#
# Author:      Sigmaplan AG, Bern
#
# Last Edited: 06.01.2020
#
# Copyright:   (c) BAFU
#
# Python:      2.7.5
# ArcGIS:      10.4.1 (ArcView License)
#------------------------------------------------------------------------------

import os
import arcpy
import datetime

starttime = datetime.datetime.now()

## *********************************************************************************************************
# Benutzereingaben und Umgebung
in_gdb = arcpy.GetParameterAsText(0) + "\\"
out_folder = arcpy.GetParameterAsText(1) + "\\"
Bearbeiter = arcpy.GetParameterAsText(2)
arcpy.env.workspace = in_gdb
arcpy.env.overwriteOutput = True

list_tables_revit = ["REVIT", "REVIT_PLAUS", "REVIT_PRIO"]
list_lyr_REVIT = ["shp_REVIT_RB.lyr", "shp_REVIT_AP.lyr", "shp_REVIT_OEB.lyr", "shp_REVIT_GISN.lyr", "shp_REVIT_PLAUS.lyr", "shp_REVIT_PRIO.lyr"]
list_lyr_MGDM = ["mgdm_OekomorpholgieSeeufer.lyr", "mgdm_Oek_L_Bedeutung.lyr", "mgdm_Nutzen_Aufwand.lyr", "mgdm_Umsetzung.lyr"]
list_subdir = ["REVIT", "MGDM_191_2"]

fields_REVIT = ['OBJECTID', 'Shape', 'Shape_Length',
                'ID_Uferlinie', 'ABSCH_ID', 'REFUGIUM', 'UFERGEH', 'HINDERNIS', 'UFERVERBAU', 'BIODURCH', # IGKB-Attribute
                'HINTERLAND', 'UFERTYP', 'BREITEFWZ', 'UFERLINIE', 'DELTA', 'UFERSUB', # IGKB-Attribute
                'LITSUB', 'TOTHOLZ', 'ROEHRICHT', 'MAKROPHYT', 'ALGEN', 'KINDERST', 'INDEX', # IGKB-Attribute
                'RBUS', 'RBFWZ', 'RBUL', 'RBHL', 'RB',
                'BAUS', 'BAFWZ', 'UTUS', 'UTFWZ',
                'ULWUS', 'ULWFWZ', 'HLW','APUS', 'APFWZ',
                'APP', 'AP', 'OEB', 'GISNP', 'GISN',
                'NUTZEN', 'BEGRUEND',
                'FRIST', 'BEM_FRIST', 'MASSN1', 'MASSN2', 'MASSN3', 'MASSN4', 'MASSN5', 'MASSN6', 'MASSN7', 'MASSN8', 'MASSN9', 'MASSN0', 'BEM_MASSN', 'MASSN_NR'
                ]
fields_OekomorphologieSeeufer = ['OBJECTID', 'Shape', 'Shape_Length', 'ID_Uferlinie', 'Methode', 'Gesamtbeurteilung_Oekomorphologie',
                                 'gewichtete_Gesamtbeurteilung', 'Uferlinie', 'Deltabildung', 'Ufersubstrat', 'Litoralsubstrat', 'Totholz', 'Hindernisse', 'Uferverbauung', # IGKB-Attribute
                                 'biologische_Durchgaengigkeit', 'Ufervegetation_landseitig', 'Makrophyten', 'Roehricht', 'Veralgung', # IGKB-Attribute
                                 'Stoerfrequenz', 'Kinderstube', 'Anbindung_Hinterland', 'Ufertyp', 'Breite_Flachwasserzone', # IGKB-Attribute  
                                 ]
fields_Oek_L_Bedeutung = ['OBJECTID', 'Shape', 'Shape_Length', 'ID_Uferlinie', 'OEB']
fields_Nutzen_Aufwand = ['OBJECTID', 'Shape', 'Shape_Length', 'ID_Uferlinie', 'NUTZEN']
fields_Umsetzung = ['OBJECTID', 'Shape', 'Shape_Length', 'ID_Uferlinie', 'FRIST']

# Pfade
path_script = os.path.dirname(sys.argv[0])
path_in = path_script.replace("\\", r"\\")

## *********************************************************************************************************
# Funktionen

def msgOut(msg):
    print msg
    arcpy.AddMessage(msg)

def errOut(err):
    print err
    print arcpy.GetMessages()
    print datetime.datetime.now()-starttime
    arcpy.AddError(err)
    arcpy.AddError(arcpy.GetMessages())
    arcpy.AddError(datetime.datetime.now()-starttime)

def CreateDir(dir, subdir):
    """ Erstellt Unterordner, sofern diese noch nicht vorhanden sind """
    if arcpy.Exists(dir + subdir):
        msgOut("")
    else:
        os.makedirs(dir + subdir)

def oekmo(nn_oekmo):
    """ Wandelt die stetigen Oekomorphologiewerte in Klassen um.
    """
    try:
        if nn_oekmo <= 1.8:
            nn_oekmo = 'naturnah_natuerlich'
        elif nn_oekmo <= 2.6:
            nn_oekmo = 'wenig_beeintraechtigt'
        elif nn_oekmo <= 3.4:
            nn_oekmo = 'beeintraechtigt'
        elif nn_oekmo <= 4.2:
            nn_oekmo = 'naturfremd'
        elif nn_oekmo <= 5:
            nn_oekmo = 'kuenstlich'
        else:
            nn_oekmo = 'nicht_bestimmt'
        return nn_oekmo
    except:
        print "\nERROR: Fehler in Berechnung Revitalisierungsbedarf"
        print "Dauer: ", datetime.datetime.now()-starttime

## *********************************************************************************************************
#  Schritt 5a: Export Daten Revitalisierungsplanung
try:
    msgOut(u"\nAblageort erstellen...")
    for subdir in list_subdir:
        CreateDir(out_folder, subdir)

    for table in list_tables_revit:
        msgOut(u"\nshp-File " + str(table) +" exportieren...")
        arcpy.FeatureClassToFeatureClass_conversion(in_gdb + table, in_gdb, "temp_" + table)
        list_attr = [a.name for a in arcpy.ListFields(in_gdb + "temp_" + table)]
        for attr in list_attr:
            if attr not in fields_REVIT:
                arcpy.DeleteField_management(in_gdb + "temp_" + table, str(attr))

        arcpy.AddField_management(in_gdb + "temp_" + table, "BEARBEITER", "TEXT", "", "", 255)
        arcpy.AddField_management(in_gdb + "temp_" + table, "EXPORTDATE", "DATE")

        with arcpy.da.UpdateCursor(in_gdb + "temp_" + table, ["BEARBEITER","EXPORTDATE"]) as rows:
            for row in rows:
                row[0] = Bearbeiter
                row[1] = datetime.datetime.now()
                rows.updateRow(row)
                
        arcpy.FeatureClassToFeatureClass_conversion(in_gdb + "temp_"  + table, out_folder + "REVIT\\", str(table) + ".shp")

        arcpy.Delete_management(in_gdb + "temp_" + table)

    msgOut(u"\nshp-File OekomorphologieSeeufer exportieren...")
    arcpy.FeatureClassToFeatureClass_conversion(in_gdb + "REVIT", in_gdb, "temp_OekomorphologieSeeufer")

    arcpy.AddField_management(in_gdb + "temp_OekomorphologieSeeufer", "Methode", "TEXT")
    arcpy.AddField_management(in_gdb + "temp_OekomorphologieSeeufer", "Gesamtbeurteilung_Oekomorphologie", "TEXT")
    with arcpy.da.UpdateCursor(in_gdb + "temp_OekomorphologieSeeufer", ["Methode", "Gesamtbeurteilung_Oekomorphologie", "INDEX"]) as rows:
        for row in rows:
            row[0] = 'IGKB'
            row[1] = oekmo(row[2])
            rows.updateRow(row)

    arcpy.AlterField_management(in_gdb + "temp_OekomorphologieSeeufer", "INDEX", "gewichtete_Gesamtbeurteilung")
    arcpy.AlterField_management(in_gdb + "temp_OekomorphologieSeeufer", "UFERLINIE", "temp_UFERLINIE") # Umweg wegen Case Sensitivity
    arcpy.AlterField_management(in_gdb + "temp_OekomorphologieSeeufer", "temp_UFERLINIE", "Uferlinie")
    arcpy.AlterField_management(in_gdb + "temp_OekomorphologieSeeufer", "DELTA", "Deltabildung")
    arcpy.AlterField_management(in_gdb + "temp_OekomorphologieSeeufer", "UFERSUB", "Ufersubstrat")
    arcpy.AlterField_management(in_gdb + "temp_OekomorphologieSeeufer", "LITSUB", "Litoralsubstrat")
    arcpy.AlterField_management(in_gdb + "temp_OekomorphologieSeeufer", "TOTHOLZ", "temp_TOTHOLZ")
    arcpy.AlterField_management(in_gdb + "temp_OekomorphologieSeeufer", "temp_TOTHOLZ", "Totholz") # Umweg wegen Case Sensitivity
    arcpy.AlterField_management(in_gdb + "temp_OekomorphologieSeeufer", "HINDERNIS", "Hindernisse")
    arcpy.AlterField_management(in_gdb + "temp_OekomorphologieSeeufer", "UFERVERBAU", "Uferverbauung")
    arcpy.AlterField_management(in_gdb + "temp_OekomorphologieSeeufer", "BIODURCH", "biologische_Durchgaengigkeit")
    arcpy.AlterField_management(in_gdb + "temp_OekomorphologieSeeufer", "UFERGEH", "Ufervegetation_landseitig")
    arcpy.AlterField_management(in_gdb + "temp_OekomorphologieSeeufer", "MAKROPHYT", "Makrophyten")
    arcpy.AlterField_management(in_gdb + "temp_OekomorphologieSeeufer", "ROEHRICHT", "temp_ROEHRICHT") # Umweg wegen Case Sensitivity
    arcpy.AlterField_management(in_gdb + "temp_OekomorphologieSeeufer", "temp_ROEHRICHT", "Roehricht")
    arcpy.AlterField_management(in_gdb + "temp_OekomorphologieSeeufer", "ALGEN", "Veralgung")
    arcpy.AlterField_management(in_gdb + "temp_OekomorphologieSeeufer", "REFUGIUM", "Stoerfrequenz")
    arcpy.AlterField_management(in_gdb + "temp_OekomorphologieSeeufer", "KINDERST", "Kinderstube")
    arcpy.AlterField_management(in_gdb + "temp_OekomorphologieSeeufer", "HINTERLAND", "Anbindung_Hinterland")
    arcpy.AlterField_management(in_gdb + "temp_OekomorphologieSeeufer", "UFERTYP", "temp_UFERTYP") # Umweg wegen Case Sensitivity
    arcpy.AlterField_management(in_gdb + "temp_OekomorphologieSeeufer", "temp_UFERTYP", "Ufertyp")
    arcpy.AlterField_management(in_gdb + "temp_OekomorphologieSeeufer", "BREITEFWZ", "Breite_Flachwasserzone")

    list_attr = [a.name for a in arcpy.ListFields(in_gdb + "temp_OekomorphologieSeeufer")]
    for attr in list_attr:
        if attr not in fields_OekomorphologieSeeufer:
            arcpy.DeleteField_management(in_gdb + "temp_OekomorphologieSeeufer", str(attr))

    arcpy.FeatureClassToFeatureClass_conversion(in_gdb + "temp_OekomorphologieSeeufer", out_folder + "MGDM_191_2\\", "OekomorphologieSeeufer.shp")
    arcpy.Delete_management(in_gdb + "temp_OekomorphologieSeeufer")

    msgOut(u"\nshp-File Oek_L_Bedeutung exportieren...")
    arcpy.FeatureClassToFeatureClass_conversion(in_gdb + "REVIT", in_gdb, "temp_Oek_L_Bedeutung")
    list_attr = [a.name for a in arcpy.ListFields(in_gdb + "temp_Oek_L_Bedeutung")]
    for attr in list_attr:
        if attr not in fields_Oek_L_Bedeutung:
            arcpy.DeleteField_management(in_gdb + "temp_Oek_L_Bedeutung", str(attr))
    arcpy.AlterField_management(in_gdb + "temp_Oek_L_Bedeutung", "OEB", "Oek_LS_Bedeutung")
    arcpy.FeatureClassToFeatureClass_conversion(in_gdb + "temp_Oek_L_Bedeutung", out_folder + "MGDM_191_2\\", "Oek_L_Bedeutung.shp")
    arcpy.Delete_management(in_gdb + "temp_Oek_L_Bedeutung")

    msgOut(u"\nshp-File Nutzen_Aufwand exportieren...")
    arcpy.FeatureClassToFeatureClass_conversion(in_gdb + "REVIT_PLAUS", in_gdb, "temp_Nutzen_Aufwand")
    list_attr = [a.name for a in arcpy.ListFields(in_gdb + "temp_Nutzen_Aufwand")]
    for attr in list_attr:
        if attr not in fields_Nutzen_Aufwand:
            arcpy.DeleteField_management(in_gdb + "temp_Nutzen_Aufwand", str(attr))
    arcpy.AlterField_management(in_gdb + "temp_Nutzen_Aufwand", "NUTZEN", "Nutzen_NL_Aufwand")
    arcpy.FeatureClassToFeatureClass_conversion(in_gdb + "temp_Nutzen_Aufwand", out_folder + "MGDM_191_2\\", "Nutzen_Aufwand.shp")
    arcpy.Delete_management(in_gdb + "temp_Nutzen_Aufwand")

    msgOut(u"\nshp-File Umsetzung exportieren...")
    arcpy.FeatureClassToFeatureClass_conversion(in_gdb + "REVIT_PRIO", in_gdb, "temp_Umsetzung")
    list_attr = [a.name for a in arcpy.ListFields(in_gdb + "temp_Umsetzung")]
    for attr in list_attr:
        if attr not in fields_Umsetzung:
            arcpy.DeleteField_management(in_gdb + "temp_Umsetzung", str(attr))
    arcpy.AlterField_management(in_gdb + "temp_Umsetzung", "FRIST", "Zeitfenster_geplante_Umsetzung")
    arcpy.FeatureClassToFeatureClass_conversion(in_gdb + "temp_Umsetzung", out_folder + "MGDM_191_2\\", "Umsetzung.shp")
    arcpy.Delete_management(in_gdb + "temp_Umsetzung")

except:
    errOut(u"ERROR: Fehler beim Export.")
    sys.exit(1)

## *********************************************************************************************************
#  Schritt 5b: lyr-Files kopieren
try:
    msgOut(u"\nlyr-Files kopieren...")
    for lyr in list_lyr_REVIT:
        arcpy.Copy_management(path_in + "\\lyr_shp\\" + str(lyr), out_folder + "REVIT\\" + str(lyr))
    for lyr in list_lyr_MGDM:
        arcpy.Copy_management(path_in + "\\lyr_shp\\" + str(lyr), out_folder + "MGDM_191_2\\" + str(lyr))
        
except:
    errOut(u"\nERROR: Fehler beim Kopieren der lyr-Files.")
    sys.exit(1)

## *********************************************************************************************************
#  Benutzeranweisung
msgOut("\n" + u"Die shp-Files wurden in den gewhlten Zielordner exportiert." + "\n")

